yoopayout

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2024 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package yoopayout describes all the necessary entities for working with YooMoney Payouts.

Package yoopayout describes all the necessary entities for working with YooMoney Payouts.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PayoutBalance

type PayoutBalance struct {
	// Amount in the selected currency.
	// Expressed as a string and written with a period, for example 10.00.
	// The number of characters after the dot depends on the selected currency.
	Value string `json:"value,omitempty"`

	// Three-letter currency code in ISO-4217 format.
	// Example: RUB. Must match the subaccount currency (recipient.gateway_id) if you separate payment flows,
	// and the account currency (shopId in your account) if you don't.
	Currency string `json:"currency,omitempty"`
}

The balance of your gateway.

type PayoutMethodType

type PayoutMethodType string
const (
	// Payments to bank cards.
	PayoutTypeBankCard PayoutMethodType = "bank_card"
	// Payments to YooMoney wallets.
	PaymentTypeYooMoney PayoutMethodType = "yoo_money"
	// Payments via SBP.
	PayoutTypeSBP PayoutMethodType = "sbp"
)

Jump to